/* fast fast_grid_template.css */
body {
  margin: 0px;
  overflow: hidden;
}

#container {
  padding:0px;
  width: 100vw;
}

#header{
  display: flex;
  align-items: center;
  padding: 10px;
  height: 44px;
}

#header-items {
  overflow: hidden;
  width: 100%;
  padding-left: 10px;
}

#sidebar-button {
  font-size: 30px;
  cursor: pointer;
  opacity: 0.9;
}
#sidebar-button:hover {
  opacity: 1.0;
}

a.navbar-brand {
  padding-left: 10px;
  padding-right: 10px;
  display: flex;
  align-items: center;
  font-size: 1.5em;
}
.app-header {
  display: contents;
  padding-left: 10px;
  white-space: nowrap;
}

.title {
  text-decoration: none;
  text-decoration-line: none;
  text-decoration-style: initial;
  text-decoration-color: initial;
  font-weight: 400;
  font-size: var(--type-ramp-plus-3-font-size);
  line-height: var(--type-ramp-plus-3-line-height);
  white-space: nowrap;
  margin-left: 0.5em;
}

img.app-logo {
  font-size: 28px;
  height: 30px;
  max-width: inherit;
}

.bk-root .bk.loader.light::after {
  background-color: var(--neutral-foreground-rest);
}

.pn-bar {
  width: 20px;
  height: 2px;
  background-color: var(--neutral-foreground-rest);
  margin: 4px 0;
}

.bk-canvas {
  padding-right: 2px !important;
}

#content {
  height: calc(100vh - 76px);
  margin: 0px;
  width: 100vw;
  display: flex;
}

#sidebar-button {
  margin-left: 10px;
  margin-right:  10px;
}

#sidebar {
  transition: all 0.2s cubic-bezier(0.945, 0.020, 0.270, 0.665);
  transform-origin: center left; /* Set the transformed position of sidebar to center left side. */
  height: 100vh;
  overflow-y: scroll;
  padding: 10px;
  margin-right: 12px;
}

#main {
  transition: all 0.2s cubic-bezier(0.945, 0.020, 0.270, 0.665);
  width: 100%;
  height: calc(100vh - 56px);
  padding: 0px;
  padding-right: 25px;
  overflow-y: scroll;
}

#sidebarCollapse {
  background: none;
  border: none;
}

.sidenav {
  padding-top: 15px;
  position: absolute;
  overflow-y: scroll;
}

.bk.card-title {
  position: absolute !important;
}
.sidenav fast-menu {
  width: 100%;
}
.sidenav a {
  padding: 8px 8px 8px 32px;
  text-decoration: none;
  color: var(--neutral-foreground-rest);
  font-size: var(--type-ramp-base-font-size);
  line-height: var(--type-ramp-base-line-height);
  display: block;
  transition: 0.3s;
}
.sidenav a:hover {
  color: #f1f1f1;
}
.sidenav fast-menu {
  background-color: var(--background-color);
  box-shadow: none;
}

.sidenav .closebtn {
  position: absolute;
  top: 0;
  right: 25px;
  font-size: 36px;
  margin-left: 50px;
}

@media screen and (max-height: 450px) {
  .sidenav {padding-top: 15px;}
  .sidenav a {font-size: 18px;}
}

.nav.flex-column {
  padding-inline-start: 0px;
}

.pn-modal-close {
  position: relative;
  float: right;
  z-index: 100;
}

.pn-modal-close:hover,
.pn-modal-close:focus {
  text-decoration: none;
  cursor: pointer;
}

.pn-busy-container {
  align-items: center;
  justify-content: center;
  display: flex;
  margin-left: auto;
}

html {
  scrollbar-face-color: var( --neutral-fill-rest);
  scrollbar-base-color: var( --neutral-fill-rest);
  scrollbar-3dlight-color: var( --neutral-fill-rest);
  scrollbar-highlight-color: var( --neutral-fill-rest);
  scrollbar-track-color: var(--background-color);
  scrollbar-arrow-color: var(--background-color);
  scrollbar-shadow-color: var( --neutral-fill-rest);
}

::-webkit-scrollbar-button {  background-color: var( --neutral-fill-rest); }
::-webkit-scrollbar-track {  background-color: var( --neutral-fill-rest);}
::-webkit-scrollbar-track-piece { background-color: var(--background-color)}
::-webkit-scrollbar-thumb { height: 50px; background-color: var( --neutral-fill-rest); border-radius: var(--corner-radius);}
::-webkit-scrollbar-corner { background-color: var();}
::-webkit-resizer { background-color: var( --neutral-fill-rest);}

#header-items {
  color: var(--neutral-foreground-rest);
}

.theme-toggle-icon {
  height: 25px;
  width: 25px;
  margin-top: 5px;
}

#made-with-panel {
  padding: .50rem;
  text-align: center;
  font-size: .75rem;
}

.fullscreen-button {
  position: absolute;
  top: 0px;
  right: 0px;
  width: 24px;
  height: 24px;
  z-index: 10000;
  opacity: 0;
  transition-delay: 0.5s;
  transition: 0.5s;
  cursor: pointer;
}

.fullscreen-button:hover {
  transition: 0.5s;
  opacity: 1;
}

.fullscreen-button:focus {
  opacity: 1;
}

#responsive-grid {
  height: 100%;
  width: calc(100% - 12px);
  padding: 10px;
}

.drag-handle {
  position: absolute;
  top: 0px;
  left: 0px;
  width: 24px;
  height: 24px;
  z-index: 10000;
  background-image: url('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCIgd2lkdGg9IjI0IiBoZWlnaHQ9IjI0Ij48cGF0aCBmaWxsPSJub25lIiBkPSJNMCAwaDI0djI0SDB6Ii8+PHBhdGggZD0iTTE2IDEzbDYuOTY0IDQuMDYyLTIuOTczLjg1IDIuMTI1IDMuNjgxLTEuNzMyIDEtMi4xMjUtMy42OC0yLjIyMyAyLjE1TDE2IDEzem0tMi03aDJ2Mmg1YTEgMSAwIDAgMSAxIDF2NGgtMnYtM0gxMHYxMGg0djJIOWExIDEgMCAwIDEtMS0xdi01SDZ2LTJoMlY5YTEgMSAwIDAgMSAxLTFoNVY2ek00IDE0djJIMnYtMmgyem0wLTR2Mkgydi0yaDJ6bTAtNHYySDJWNmgyem0wLTR2MkgyVjJoMnptNCAwdjJINlYyaDJ6bTQgMHYyaC0yVjJoMnptNCAwdjJoLTJWMmgyeiIvPjwvc3ZnPg==');
  opacity: 0;
  transition-delay: 0.5s;
  transition: 0.5s;
}

.drag-handle:hover {
  transition: 0.5s;
  opacity: 1;
  cursor: move;
}

.drag-handle:focus {
  opacity: 1;
}

.react-resizable {
  position: relative;
}
.react-resizable-handle {
  position: absolute;
  width: 20px;
  height: 20px;
  background-repeat: no-repeat;
  background-origin: content-box;
  box-sizing: border-box;
  background-image: url('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA2IDYiIHN0eWxlPSJiYWNrZ3JvdW5kLWNvbG9yOiNmZmZmZmYwMCIgeD0iMHB4IiB5PSIwcHgiIHdpZHRoPSI2cHgiIGhlaWdodD0iNnB4Ij48ZyBvcGFjaXR5PSIwLjMwMiI+PHBhdGggZD0iTSA2IDYgTCAwIDYgTCAwIDQuMiBMIDQgNC4yIEwgNC4yIDQuMiBMIDQuMiAwIEwgNiAwIEwgNiA2IEwgNiA2IFoiIGZpbGw9IiMwMDAwMDAiLz48L2c+PC9zdmc+');
  background-position: bottom right;
  padding: 0 3px 3px 0;
}
.react-resizable-handle-sw {
  bottom: 0;
  left: 0;
  cursor: sw-resize;
  transform: rotate(90deg);
}
.react-resizable-handle-se {
  bottom: 0;
  right: 0;
  cursor: se-resize;
}
.react-resizable-handle-nw {
  top: 0;
  left: 0;
  cursor: nw-resize;
  transform: rotate(180deg);
}
.react-resizable-handle-ne {
  top: 0;
  right: 0;
  cursor: ne-resize;
  transform: rotate(270deg);
}
.react-resizable-handle-w,
.react-resizable-handle-e {
  top: 50%;
  margin-top: -10px;
  cursor: ew-resize;
}
.react-resizable-handle-w {
  left: 0;
  transform: rotate(135deg);
}
.react-resizable-handle-e {
  right: 0;
  transform: rotate(315deg);
}
.react-resizable-handle-n,
.react-resizable-handle-s {
  left: 50%;
  margin-left: -10px;
  cursor: ns-resize;
}
.react-resizable-handle-n {
  top: 0;
  transform: rotate(225deg);
}
.react-resizable-handle-s {
  bottom: 0;
  transform: rotate(45deg);
}

.react-grid-layout {
  position: relative;
  transition: height 200ms ease;
}
.react-grid-item {
  transition: all 200ms ease;
  transition-property: left, top;
}
.react-grid-item.cssTransforms {
  transition-property: transform;
}
.react-grid-item.resizing {
  z-index: 1;
  will-change: width, height;
}

.react-grid-item.react-draggable-dragging {
  transition: none;
  z-index: 3;
  will-change: transform;
}

.react-grid-item.dropping {
  visibility: hidden;
}

.react-grid-item.react-grid-placeholder {
  background: var(--accent-fill-rest);
  opacity: 0.2;
  transition-duration: 100ms;
  z-index: 2;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -o-user-select: none;
  user-select: none;
}

.react-grid-item > .react-resizable-handle {
  position: absolute;
  width: 20px;
  height: 20px;
  bottom: 0px;
  right: 0px;
  cursor: se-resize;
}

.react-grid-item > .react-resizable-handle::after {
  content: "";
  position: absolute;
  right: 3px;
  bottom: 3px;
  width: 5px;
  height: 5px;
  border-right: 2px solid rgba(0, 0, 0, 0.4);
  border-bottom: 2px solid rgba(0, 0, 0, 0.4);
}

.react-resizable-hide > .react-resizable-handle {
  display: none;
}

.react-grid-item > fast-card {
  margin: 0px;
}
div.pn-wrapper {
  position: relative;
  background: var(--background-color)
}
